==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NamespaceRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.AccountsNamesDTO;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicIds;
import io.nem.sdk.openapi.vertx.model.MosaicsNamesDTO;
import io.nem.sdk.openapi.vertx.model.NamespaceIds;
import io.nem.sdk.openapi.vertx.model.NamespaceInfoDTO;
import io.nem.sdk.openapi.vertx.model.NamespaceNameDTO;
import io.nem.sdk.openapi.vertx.model.NamespacesInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class NamespaceRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi delegate;

	public NamespaceRoutesApi(io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get readable names for a set of accountIds
     * Returns friendly names for accounts.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountsNames(AccountIds accountIds, Handler<AsyncResult<AccountsNamesDTO>> resultHandler) {
        delegate.getAccountsNames(accountIds, resultHandler);
    }

    /**
     * Get readable names for a set of accountIds
     * Returns friendly names for accounts.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<AccountsNamesDTO> rxGetAccountsNames(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountsNames(accountIds, fut);
        }));
    }
    /**
     * Get readable names for a set of mosaics
     * Returns friendly names for mosaics.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsNames(MosaicIds mosaicIds, Handler<AsyncResult<MosaicsNamesDTO>> resultHandler) {
        delegate.getMosaicsNames(mosaicIds, resultHandler);
    }

    /**
     * Get readable names for a set of mosaics
     * Returns friendly names for mosaics.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsNamesDTO> rxGetMosaicsNames(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsNames(mosaicIds, fut);
        }));
    }
    /**
     * Get namespace information
     * Gets the namespace for a given namespace identifier.
     * @param namespaceId Namespace identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespace(String namespaceId, Handler<AsyncResult<NamespaceInfoDTO>> resultHandler) {
        delegate.getNamespace(namespaceId, resultHandler);
    }

    /**
     * Get namespace information
     * Gets the namespace for a given namespace identifier.
     * @param namespaceId Namespace identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespaceInfoDTO> rxGetNamespace(String namespaceId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespace(namespaceId, fut);
        }));
    }
    /**
     * Get namespaces created by an account
     * Gets an array of namespaces for a given account address.
     * @param accountId Account public key or address. (required)
     * @param pageSize Number of transactions to return for each request. (optional, default to 10)
     * @param id Namespace identifier up to which transactions are returned. (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesFromAccount(String accountId, Integer pageSize, String id, Handler<AsyncResult<NamespacesInfoDTO>> resultHandler) {
        delegate.getNamespacesFromAccount(accountId, pageSize, id, resultHandler);
    }

    /**
     * Get namespaces created by an account
     * Gets an array of namespaces for a given account address.
     * @param accountId Account public key or address. (required)
     * @param pageSize Number of transactions to return for each request. (optional, default to 10)
     * @param id Namespace identifier up to which transactions are returned. (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespacesInfoDTO> rxGetNamespacesFromAccount(String accountId, Integer pageSize, String id) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesFromAccount(accountId, pageSize, id, fut);
        }));
    }
    /**
     * Get namespaces for given array of addresses
     * Gets namespaces for a given array of addresses.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesFromAccounts(AccountIds accountIds, Handler<AsyncResult<NamespacesInfoDTO>> resultHandler) {
        delegate.getNamespacesFromAccounts(accountIds, resultHandler);
    }

    /**
     * Get namespaces for given array of addresses
     * Gets namespaces for a given array of addresses.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespacesInfoDTO> rxGetNamespacesFromAccounts(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesFromAccounts(accountIds, fut);
        }));
    }
    /**
     * Get readable names for a set of namespaces
     * Returns friendly names for namespaces.
     * @param namespaceIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesNames(NamespaceIds namespaceIds, Handler<AsyncResult<List<NamespaceNameDTO>>> resultHandler) {
        delegate.getNamespacesNames(namespaceIds, resultHandler);
    }

    /**
     * Get readable names for a set of namespaces
     * Returns friendly names for namespaces.
     * @param namespaceIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<NamespaceNameDTO>> rxGetNamespacesNames(NamespaceIds namespaceIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesNames(namespaceIds, fut);
        }));
    }

    public static NamespaceRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi arg) {
        return arg != null ? new NamespaceRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NamespaceRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.AccountsNamesDTO;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicIds;
import io.nem.sdk.openapi.vertx.model.MosaicsNamesDTO;
import io.nem.sdk.openapi.vertx.model.NamespaceIds;
import io.nem.sdk.openapi.vertx.model.NamespaceInfoDTO;
import io.nem.sdk.openapi.vertx.model.NamespaceNameDTO;
import io.nem.sdk.openapi.vertx.model.NamespacesInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class NamespaceRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi delegate;

	public NamespaceRoutesApi(io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get readable names for a set of accountIds
     * Returns friendly names for accounts.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountsNames(AccountIds accountIds, Handler<AsyncResult<AccountsNamesDTO>> resultHandler) {
        delegate.getAccountsNames(accountIds, resultHandler);
    }

    /**
     * Get readable names for a set of accountIds
     * Returns friendly names for accounts.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<AccountsNamesDTO> rxGetAccountsNames(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountsNames(accountIds, fut);
        }));
    }
    /**
     * Get readable names for a set of mosaics
     * Returns friendly names for mosaics.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsNames(MosaicIds mosaicIds, Handler<AsyncResult<MosaicsNamesDTO>> resultHandler) {
        delegate.getMosaicsNames(mosaicIds, resultHandler);
    }

    /**
     * Get readable names for a set of mosaics
     * Returns friendly names for mosaics.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsNamesDTO> rxGetMosaicsNames(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsNames(mosaicIds, fut);
        }));
    }
    /**
     * Get namespace information
     * Gets the namespace for a given namespace identifier.
     * @param namespaceId Namespace identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespace(String namespaceId, Handler<AsyncResult<NamespaceInfoDTO>> resultHandler) {
        delegate.getNamespace(namespaceId, resultHandler);
    }

    /**
     * Get namespace information
     * Gets the namespace for a given namespace identifier.
     * @param namespaceId Namespace identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespaceInfoDTO> rxGetNamespace(String namespaceId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespace(namespaceId, fut);
        }));
    }
    /**
     * Get namespaces created by an account
     * Gets an array of namespaces for a given account address.
     * @param accountId Account public key or address. (required)
     * @param pageSize Number of transactions to return for each request. (optional, default to 10)
     * @param id Namespace identifier up to which transactions are returned. (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesFromAccount(String accountId, Integer pageSize, String id, Handler<AsyncResult<NamespacesInfoDTO>> resultHandler) {
        delegate.getNamespacesFromAccount(accountId, pageSize, id, resultHandler);
    }

    /**
     * Get namespaces created by an account
     * Gets an array of namespaces for a given account address.
     * @param accountId Account public key or address. (required)
     * @param pageSize Number of transactions to return for each request. (optional, default to 10)
     * @param id Namespace identifier up to which transactions are returned. (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespacesInfoDTO> rxGetNamespacesFromAccount(String accountId, Integer pageSize, String id) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesFromAccount(accountId, pageSize, id, fut);
        }));
    }
    /**
     * Get namespaces for given array of addresses
     * Gets namespaces for a given array of addresses.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesFromAccounts(AccountIds accountIds, Handler<AsyncResult<NamespacesInfoDTO>> resultHandler) {
        delegate.getNamespacesFromAccounts(accountIds, resultHandler);
    }

    /**
     * Get namespaces for given array of addresses
     * Gets namespaces for a given array of addresses.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NamespacesInfoDTO> rxGetNamespacesFromAccounts(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesFromAccounts(accountIds, fut);
        }));
    }
    /**
     * Get readable names for a set of namespaces
     * Returns friendly names for namespaces.
     * @param namespaceIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getNamespacesNames(NamespaceIds namespaceIds, Handler<AsyncResult<List<NamespaceNameDTO>>> resultHandler) {
        delegate.getNamespacesNames(namespaceIds, resultHandler);
    }

    /**
     * Get readable names for a set of namespaces
     * Returns friendly names for namespaces.
     * @param namespaceIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<NamespaceNameDTO>> rxGetNamespacesNames(NamespaceIds namespaceIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNamespacesNames(namespaceIds, fut);
        }));
    }

    public static NamespaceRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NamespaceRoutesApi arg) {
        return arg != null ? new NamespaceRoutesApi(arg) : null;
    }
}
